@@ -173,7 +173,7 @@ class SoapController(controllers.Controller):
         cherrypy.response.body = str(envelope)
     
     @tgexpose("genshi:tgwebservices.templates.soap",
-              content_type="text/xml;charset=utf-8", format="xml")
+              content_type="application/soap+xml;charset=utf-8", format="xml")
     def index(self):
         """Processes SOAP requests and generates the responses."""
         # get request data and produce an ElementTree that we can work with.
